==> haskell-text-builder-0.6.5.1-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-builder
version: 0.6.5.1
id: text-builder-0.6.5.1-JuNaHsoGefEGzw1ZvbMhR3
key: text-builder-0.6.5.1-JuNaHsoGefEGzw1ZvbMhR3
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/text-builder
synopsis: An efficient strict text builder
category: Text
abi: 9cd0421c9dfda4e33df94413bec434a3
exposed: True
exposed-modules:
    Text.Builder
hidden-modules: Text.Builder.UTF16 Text.Builder.Prelude
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-builder-0.6.5.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-builder-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-builder-0.6.5.1
hs-libraries: HStext-builder-0.6.5.1-JuNaHsoGefEGzw1ZvbMhR3
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    bytestring-0.10.8.2 deferred-folds-0.9.10.1-K5VZp4arp1xIcESjFo0yvV
    text-1.2.3.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-text-builder/html/text-builder.haddock
haddock-html: /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-0.6.5-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-builder
version: 0.6.5
id: text-builder-0.6.5-HlQHg7M7Yt1FgX2wyht5nb
key: text-builder-0.6.5-HlQHg7M7Yt1FgX2wyht5nb
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/text-builder
synopsis: An efficient strict text builder
category: Text
abi: 54c5e7fdec19397be6ff29f106af3a24
exposed: True
exposed-modules:
    Text.Builder
hidden-modules: Text.Builder.UTF16 Text.Builder.Prelude
import-dirs: /usr/lib/ghc-8.6.4/site-local/text-builder-0.6.5
library-dirs: /usr/lib/ghc-8.6.4/site-local/text-builder-0.6.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/text-builder-0.6.5
hs-libraries: HStext-builder-0.6.5-HlQHg7M7Yt1FgX2wyht5nb
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    bytestring-0.10.8.2 deferred-folds-0.9.10-1KXdsayRTfm2I1IX4HXzIG
    text-1.2.3.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-text-builder/html/text-builder.haddock
haddock-html: /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
